Translate Toolkit 3.13.5
************************

*Released on 4 October 2024*

This release contains improvements and bug fixes.

Changes
=======

Formats and Converters
----------------------

- Android

  - Fixed newlines serialization

- PHP

  - Fixed escaping quotes in keys

- HTML

  - Enable translation of the label tag


Contributors
============

This release was made possible by the following people:

Michal Čihař, John Stef
